<?php
/**
 * Hierarchy Tree Data Formatter (JSON)
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2015.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  HierarchyTree_DataFormatter
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
namespace finc\Hierarchy\TreeDataFormatter;

/**
 * Hierarchy Tree Data Formatter (JSON)
 *
 * @category VuFind
 * @package  HierarchyTree_DataFormatter
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
class NoCollections extends \VuFind\Hierarchy\TreeDataFormatter\Json
{
    /**
     * {@inheritdoc}
     * Always returns false in our case, since we always want Record links
     * @param object $fields
     * @return bool
     */
    protected function isCollection($fields)
    {
        //always return false to ensure Record-Links only
        return false;
    }

    /**
     * {@inheritdoc}
     * Our version avoids unnecessary evaluation of getTitlesInHierarchy()
     * @param object $record
     * @param string $parentID
     * @return string
     */
    protected function pickTitle($record, $parentID)
    {
        if (!isset($parentID) || empty($parentID)) {
            return $record->title ?? $record->id;
        }
        return parent::pickTitle($record, $parentID);
    }


    /**
     * Sort Nodes
     * Convert an unsorted array of [ key, value ] pairs into a sorted array
     * of values.
     *
     * @param array $array The array of arrays to sort
     *
     * @return array
     */
    protected function sortNodes($array)
    {
        // Sort arrays based on first element
        $sorter = function ($a, $b) {
            return strnatcmp($a[0], $b[0]);
        };
        usort($array, $sorter);

        // Collapse array to remove sort values
        $mapper = function ($i) {
            return $i[1];
        };
        return array_map($mapper, $array);
    }
}
