<?php
/**
 * Delegator Factory for SolrMarc record drivers. Enables specialized rules
 * for \finc\RecordDriver\SolrMarcFincTrait::getURLs
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2021.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  RecordDrivers
 * @author   Dorian Merz <mer@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace finc\RecordDriver;

use Interop\Container\ContainerInterface;

/**
 * Delegator Factory for SolrMarc record drivers. Enables specialized rules
 * for \finc\RecordDriver\SolrMarcFincTrait::getURLs
 *
 * @category VuFind
 * @package  RecordDrivers
 * @author   Dorian Merz <mer@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class SolrMarcUrlRulesDelegatorFactory
{
    /**
     * Creates a delegator of VuFind/Search to register several listeners.
     *
     * @param ContainerInterface $container
     * @param string $name
     * @param callable $callback
     * @param array|null $options
     *
     * @return mixed
     */
    public function __invoke(
        ContainerInterface $container,
        $name,
        callable $callback,
        array $options = null
    ) {
        $instance = call_user_func($callback);

        $urlRules = $container->get('VuFind\YamlReader')->get('SolrMarcUrlRules.yaml');
        if (!empty($urlRules)) {
            if (isset($urlRules['rules']) && isset($urlRules['stopFlags'])) {
                $instance->urlRules = $urlRules;
            }
        }

        return $instance;
    }
}
