<?php
/**
 * Record Tab Invokable Factory Class
 * for HierarchyTree tab
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library, 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  RecordTab
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
namespace finc\RecordTab;

use Zend\ServiceManager\ServiceManager;

/**
 * Record Tab Invokable Factory Class
 * for HierarchyTree tab
 *
 * @category VuFind
 * @package  RecordTab
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 *
 * @codeCoverageIgnore
 */
class HierarchyTreeFactory
{
    /**
     * Factory for HierarchyTree tab plugin.
     *
     * @param ServiceManager $sm Service manager.
     *
     * @return HierarchyTree
     */
    public function __invoke(ServiceManager $sm, $requestedName, array $options = null)
    {
        if (!empty($options)) {
            throw new \ConfigurationException('Unexpected options');
        }
        return new $requestedName(
            $sm->get('VuFind\Config\PluginManager')->get('config')
        );
    }
}
